@@ -120,8 +120,7 @@ class MonitorField(models.DateTimeField):
 
     def deconstruct(self):
         name, path, args, kwargs = super(MonitorField, self).deconstruct()
-        if self.monitor is not None:
-            kwargs['monitor'] = self.monitor
+        kwargs['monitor'] = self.monitor
         if self.when is not None:
             kwargs['when'] = self.when
         return name, path, args, kwargs
@@ -230,6 +229,10 @@ class SplitField(models.TextField):
         except AttributeError:
             return value
 
+    def deconstruct(self):
+        name, path, args, kwargs = super(SplitField, self).deconstruct()
+        kwargs['no_excerpt_field'] = True
+        return name, path, args, kwargs
 
 # allow South to handle these fields smoothly
 try:
